function mucreatemodel(name)
% usage MUCREATEMODEL(NAME)
% 
% NAME = codename for the model (e.g. 'damu')
% creates a model made by several components 
% parsing the codename (e.g. 'damu') and loking for components
% from the list defined in mu_initialize_components 
%
% See also MUPATH, MULOAD, MUSET, MUMODEL, MUFITMENU, MUFIT,
% MUSAVEMODEL, MURIG, MULABSAVE, MULIST, MUPLOT
%
% HELP MU for a list,  

global MU_MODEL
global MU_COMPONENT

if isfield(MU_MODEL,'ALPHA') % old model exists
    if MU_MODEL.ALPHA~=0       
        a=MU_MODEL.ALPHA;                     % save some variables
        ft=MU_MODEL.FLAG.TYPE; %'decay'
        fd=MU_MODEL.FLAG.DENOMINATOR;% 'data'
        if ~isfield(MU_MODEL.FLAG,'LOGVERSION')
            lv=1;
        else
            lv=MU_MODEL.FLAG.LOGVERSION;
        end
        b=MU_MODEL.BATCHMODE; % 'command'
        fg=MU_MODEL.GROUPING(1).FORWARD;
        bg=MU_MODEL.GROUPING(1).BACKWARD;
        r=MU_MODEL.RANGE;
        bin=MU_MODEL.BIN;
    else   % is empty
        a=1;                          % define defaults
        ft='Polarization'; %'Decay'
        fd='Fit';% 'Data'
        b='Batch'; % 'Interactive'
        fg=1;
        bg=2;
        r=[1 4000];
        bin=1;
        lv=1;
    end
else % does not exist
    a=1;
    ft='polarization'; %'decay'
    fd='fit';% 'data'
    b='batch'; % 'command'
    fg=1;
    bg=2;
    r=[1 4000];
    bin=1;
    lv=1;
end
n=mugetcomponent(char(name)); % gets the order number in the MU_COMPONENT list
clear global MU_MODEL % clear old model if it exists
global MU_MODEL
l=length(n); % how may components
MU_MODEL.NAME=name;
MU_MODEL.COMPONENTNUMBER=l;
MU_MODEL.ALPHA=a;
MU_MODEL.FLAG.TYPE=ft;
MU_MODEL.FLAG.DENOMINATOR=fd;
MU_MODEL.FLAG.LOGVERSION=lv;
MU_MODEL.BATCHMODE=b;
MU_MODEL.GROUPING(1).FORWARD=fg;
MU_MODEL.GROUPING(1).BACKWARD=bg;
MU_MODEL.RANGE=r;
MU_MODEL.BIN=bin;
par=0;
p=0;
for k=1:l;
    MU_MODEL.COMPONENT(k).NAME=char(MU_COMPONENT.NAME(n(k)));
    pnum=MU_COMPONENT.PARAMETER(n(k)).NUMBER;
    MU_MODEL.COMPONENT(k).PARAMETERNUMBER=pnum;
    pname=MU_COMPONENT.PARAMETER(n(k)).NAME;
    MU_MODEL.COMPONENT(k).SHARE=par+[1:pnum]; % index in p
    par=par+pnum;
    for j=1:MU_COMPONENT.PARAMETER(n(k)).NUMBER
        p=p+1;
        MU_MODEL.COMPONENT(k).PARAMETER(j).NAME= char(pname(j));
        MU_MODEL.COMPONENT(k).PARAMETER(j).VALUE=0;
        MU_MODEL.COMPONENT(k).PARAMETER(j).FLAG='~';
        MU_MODEL.COMPONENT(k).PARAMETER(j).SHARE=p;
    end
end
mufit_gui % force layout
