function f=muedge(par,data)
% computes t0 for ISIS
%  Y0 = MUEDGE(P,X)
%  where P = t0, Ntot are variational parameters,
%  and X is a vector, returns
%  muon beam time structure (unpolarized) as from 
% http://www.fis.unipr.it/~derenzi/dispense/pmwiki.php?n=MuSR.PulsedMuonBeam
%
% D cannot be fitted because it correlated largely with Ntot
% chi2 is bad on MUSR beacuse of events preceding t=0 (spillover
% from EMU)
%
%  CHI2 = edge(P,[X; Y; Delta_Y])
%  where Y and Delta_Y are experimental data and errorbar vectors,
%  respectively, returns Chi-square:  CHI2 = sum(((Y-Y0)./Delta_Y).^);
%
%  CHI2 = edge(P,[X; Y])
%  is the same as above, with Delta_Y = ones(size(X));
%  theoretical function
global MU_TABLE
t0=par(1);
t=data(1,:)-t0;
Ntot=par(2);
D=80; % (ns) pulse width (FWHM)
a=6/D^3; % proton parabole, so that area =1
c=3/2/D;
tau=26.003 ; % (ns) pion lifetime
T=MU_TABLE.TAUMU; % (ns) muon lifetime
costant=(((-D^2/4-2*tau^2)*a+c)*(exp(D/(2*tau))-exp(-D/(2*tau)))+a*tau*D*(exp(D/(2*tau))+exp(-D/(2*tau))));
cost1=c-2*a*tau^2;
cost2=(a*(D^2/4+tau*D+2*tau^2)-c);
m2=cost1*(1-exp(-t/T-D/2/T))+...
        cost2*tau/(T-tau)*(exp(-(D+2*t)/2/T)-exp(-(D+2*t)/2/tau))+...
        +2*a*tau*(t-T+(D/2+T)*exp(-(D+2*t)/2/T))...
        -a*(t.^2-2*T*t+2*T^2-(D^2/4+T*D+2*T^2)*exp(-(D+2*t)/2/T));
m2=m2.*(t<=D/2).*(t>-D/2);
costant=(c-a*(D^2/4+2*tau^2))*(exp(D/2/tau)-exp(-D/2/tau))+a*tau*D* ...
        (exp(D/2/tau)+exp(-D/2/tau));
M2=cost1*(1-exp(-D/T))+...
        cost2*tau/(T-tau)*(exp(-D/T)-exp(-D/tau))+...
        +2*a*tau*(D/2-T+(D/2+T)*exp(-D/T))...
        -a*(D^2/4-T*D+2*T^2-(D^2/4+T*D+2*T^2)*exp(-D/T)); % m2(D/2)
m1=costant* tau/(T-tau)...
    *(exp(D/2*(1/T-1/tau)-t/T)-exp(-t/tau))+M2*exp((D-2*t)/(2*T));
m1=m1.*(t>D/2);
f=Ntot*(m1+m2);%+par(4)*exp(-data(1,:)/T);
if (size(data,1)==2),    %chi-square, error = 1
  f = sum((data(2,:) - f).^2);
elseif (size(data,1)>2), %chi-square, error = 3rd row of data
  f = sum(((data(2,:) - f)./data(3,:)).^2);
end
