% atomic function, generates normalized function on a given time array 
% Zero and Longitudinal-field Gaussian Kubo Toyabe fuction
% Uses the Dawson function Faddeeva_Dawson from the Faddeeva package
% http://ab-initio.mit.edu/Faddeeva-MATLAB.zip

function y=mugkt(P,t0,dt,N)
% P(1): omega = 2*pi*B(G)*MU_TABLE.GAMU
% P(2): Delta

t=t0+(0:N-1)*dt;
DD=P(2)^2;
DDtt=DD*t.^2;

argf=P(1)/(sqrt(2)*P(2));
fdc=Faddeeva_Dawson(argf);
sqrt2=sqrt(2);

if (P(1)),
    Aa=real(exp(-.5*DDtt + i*P(1)*t).*Faddeeva_Dawson(-argf - i*P(2)*t/ ...
                                                      sqrt2));
    Aa(find(isnan(Aa)))=0; % empirical fix 
    Aa(find(isinf(Aa)))=0; % bi-empirical fix
    A=sqrt2/P(2)*(Aa + fdc);

    y = 1 - 2*DD/P(1)^2*(1-exp(-.5*DD*t.^2).*cos(P(1)*t)) + 2*DD^2/P(1)^3*A; 
else
    y = (1 + 2*(1-DD*t.^2).*exp(-.5*DD*t.^2))/3;
end
        

